"""Module which contains fixture data for use in testing the orodha_user_client."""

MOCK_CREDENTIALS = {
    "server_url": "http://some_server_url",
    "realm_name": "some_realm_name",
    "client_id": "some_client_id",
    "client_secret_key": "some_secret_key",
    "username": "some_username",
    "password": "some_password",
    }

MOCK_BASE_URL = "http://some_other_url"
